@@ -500,11 +500,13 @@ public void test010() throws JavaModelException {
 			"  public X() {\n" + 
 			"  }\n" + 
 			"  public static void foo(Num num_) {\n" + 
-			"    {\n" + 
-			"      {\n" + 
-			"        int i_j;\n" + 
-			"        <SelectOnName:i_j>;\n" + 
-			"      }\n" + 
+			"    switch (num_) {\n" + 
+			"    case THREE ->\n" + 
+			"        {\n" + 
+			"          int i_j;\n" + 
+			"          System.out.println(<SelectOnName:i_j>);\n" + 
+			"          break;\n" + 
+			"        }\n" + 
 			"    }\n" + 
 			"  }\n" + 
 			"}\n";
@@ -786,285 +788,4 @@ public void test017() throws JavaModelException {
 	checkMethodParse(string.toCharArray(), selectionStart, selectionEnd, expectedSelection, expectedUnitDisplayString,
 			selectionIdentifier, expectedReplacedSource, testName);
 }
-public void test018() throws JavaModelException {
-	String string =  "import org.eclipse.jdt.annotation.*;\n" + 
-			"import java.util.function.*;\n" + 
-			"interface IN0 {} \n" + 
-			"interface IN1 extends IN0 {} \n" + 
-			"interface IN2 extends IN0 {}\n" + 
-			"public class X {\n" + 
-			"	 IN1 n_1() { return new IN1() {}; } \n" + 
-			"	IN2 n_2() { return null; } \n" + 
-			"	<M> void m( Supplier< M> m2) { } \n" + 
-			"	void testSw(int i) { \n" + 
-			"		m(switch(i) { \n" + 
-			"			case 1 -> this::n_1; \n" + 
-			"			default -> this::n_2; }); \n" + 
-			"	}\n" + 
-			"}";
-
-	String selection = "n_1";
-	String selectKey = "<SelectionOnReferenceExpressionName:this::";
-	String expectedSelection = selectKey + selection + ">";
-
-	String selectionIdentifier = "n_1";
-	String expectedUnitDisplayString =
-			"import org.eclipse.jdt.annotation.*;\n" + 
-			"import java.util.function.*;\n" + 
-			"interface IN0 {\n" + 
-			"}\n" + 
-			"interface IN1 extends IN0 {\n" + 
-			"}\n" + 
-			"interface IN2 extends IN0 {\n" + 
-			"}\n" + 
-			"public class X {\n" + 
-			"  public X() {\n" + 
-			"  }\n" + 
-			"  IN1 n_1() {\n" + 
-			"  }\n" + 
-			"  IN2 n_2() {\n" + 
-			"  }\n" + 
-			"  <M>void m(Supplier<M> m2) {\n" + 
-			"  }\n" + 
-			"  void testSw(int i) {\n" + 
-			"    m(switch (i) {\n" + 
-			"case 1 ->\n" + 
-			" <SelectionOnReferenceExpressionName:this::n_1>;\n" + 
-			"default ->\n" + 
-			" this::n_2;\n" + 
-			"});\n" + 
-			"  }\n" + 
-			"}\n";
-	String expectedReplacedSource = "this::n_1";
-	String testName = "X.java";
-
-	int selectionStart = string.lastIndexOf(selection);
-	int selectionEnd = selectionStart + selection.length() - 1;
-
-	checkMethodParse(string.toCharArray(), selectionStart, selectionEnd, expectedSelection, expectedUnitDisplayString,
-			selectionIdentifier, expectedReplacedSource, testName);
-}
-public void test019() throws JavaModelException {
-	String string =  "import org.eclipse.jdt.annotation.*;\n" + 
-			"import java.util.function.*;\n" + 
-			"interface IN0 {} \n" + 
-			"interface IN1 extends IN0 {} \n" + 
-			"interface IN2 extends IN0 {}\n" + 
-			"public class X {\n" + 
-			"	 IN1 n_1() { return new IN1() {}; } \n" + 
-			"	IN2 n_2() { return null; } \n" + 
-			"	<M> void m( Supplier< M> m2) { } \n" + 
-			"	void testSw(int i) { \n" + 
-			"		m(switch(i) { \n" + 
-			"			case 2 -> () -> n_1(); \n" + 
-			"			default -> this::n_2; }); \n" + 
-			"	}\n" + 
-			"}";
-
-	String selection = "n_1";
-	String selectKey = "<SelectOnMessageSend:";
-	String expectedSelection = selectKey + selection + "()>";
-
-	String selectionIdentifier = "n_1";
-	String expectedUnitDisplayString =
-			"import org.eclipse.jdt.annotation.*;\n" + 
-			"import java.util.function.*;\n" + 
-			"interface IN0 {\n" + 
-			"}\n" + 
-			"interface IN1 extends IN0 {\n" + 
-			"}\n" + 
-			"interface IN2 extends IN0 {\n" + 
-			"}\n" + 
-			"public class X {\n" + 
-			"  public X() {\n" + 
-			"  }\n" + 
-			"  IN1 n_1() {\n" + 
-			"  }\n" + 
-			"  IN2 n_2() {\n" + 
-			"  }\n" + 
-			"  <M>void m(Supplier<M> m2) {\n" + 
-			"  }\n" + 
-			"  void testSw(int i) {\n" + 
-			"    m(switch (i) {\n" + 
-			"case 2 ->\n" + 
-			" () -> <SelectOnMessageSend:n_1()>;\n" + 
-			"default ->\n" + 
-			" this::n_2;\n" + 
-			"});\n" + 
-			"  }\n" + 
-			"}\n";
-	String expectedReplacedSource = "n_1()";
-	String testName = "X.java";
-
-	int selectionStart = string.lastIndexOf(selection);
-	int selectionEnd = selectionStart + selection.length() - 1;
-
-	checkMethodParse(string.toCharArray(), selectionStart, selectionEnd, expectedSelection, expectedUnitDisplayString,
-			selectionIdentifier, expectedReplacedSource, testName);
-}
-public void test020() throws JavaModelException {
-	String string =  "import org.eclipse.jdt.annotation.*;\n" + 
-			"import java.util.function.*;\n" + 
-			"interface IN0 {} \n" + 
-			"interface IN1 extends IN0 {} \n" + 
-			"interface IN2 extends IN0 {}\n" + 
-			"public class X {\n" + 
-			"	 IN1 n_1() { return new IN1() {}; } \n" + 
-			"	IN2 n_2() { return null; } \n" + 
-			"	<M> void m( Supplier< M> m2) { } \n" + 
-			"	void testSw(int i) { \n" + 
-			"		m(switch(i) { \n" + 
-			"			default -> this::n_2; }); \n" + 
-			"	}\n" + 
-			"}";
-
-	String selection = "n_2";
-	String selectKey = "<SelectionOnReferenceExpressionName:this::";
-	String expectedSelection = selectKey + selection + ">";
-
-	String selectionIdentifier = "n_2";
-	String expectedUnitDisplayString =
-			"import org.eclipse.jdt.annotation.*;\n" + 
-			"import java.util.function.*;\n" + 
-			"interface IN0 {\n" + 
-			"}\n" + 
-			"interface IN1 extends IN0 {\n" + 
-			"}\n" + 
-			"interface IN2 extends IN0 {\n" + 
-			"}\n" + 
-			"public class X {\n" + 
-			"  public X() {\n" + 
-			"  }\n" + 
-			"  IN1 n_1() {\n" + 
-			"  }\n" + 
-			"  IN2 n_2() {\n" + 
-			"  }\n" + 
-			"  <M>void m(Supplier<M> m2) {\n" + 
-			"  }\n" + 
-			"  void testSw(int i) {\n" + 
-			"    m(switch (i) {\n" + 
-			"default ->\n" + 
-			" <SelectionOnReferenceExpressionName:this::n_2>;\n" + 
-			"});\n" + 
-			"  }\n" + 
-			"}\n";
-	String expectedReplacedSource = "this::n_2";
-	String testName = "X.java";
-
-	int selectionStart = string.lastIndexOf(selection);
-	int selectionEnd = selectionStart + selection.length() - 1;
-
-	checkMethodParse(string.toCharArray(), selectionStart, selectionEnd, expectedSelection, expectedUnitDisplayString,
-			selectionIdentifier, expectedReplacedSource, testName);
-}
-public void test021() throws JavaModelException {
-	String string =  "import org.eclipse.jdt.annotation.*;\n" + 
-			"import java.util.function.*;\n" + 
-			"interface IN0 {} \n" + 
-			"interface IN1 extends IN0 {} \n" + 
-			"interface IN2 extends IN0 {}\n" + 
-			"public class X {\n" + 
-			"	 IN1 n_1(int ijk) { return new IN1() {}; } \n" + 
-			"	IN2 n_2() { return null; } \n" + 
-			"	<M> void m( Supplier< M> m2) { } \n" + 
-			"	void testSw(int ijk) { \n" + 
-			"		m(switch(ijk) { \n" + 
-			"			default -> () -> n_1(ijk); }); \n" + 
-			"	}\n" + 
-			"}";
-
-	String selection = "n_1";
-	String selectKey = "<SelectOnMessageSend:";
-	String expectedSelection = selectKey + selection + "(ijk)>";
-
-	String selectionIdentifier = "n_1";
-	String expectedUnitDisplayString =
-			"import org.eclipse.jdt.annotation.*;\n" + 
-			"import java.util.function.*;\n" + 
-			"interface IN0 {\n" + 
-			"}\n" + 
-			"interface IN1 extends IN0 {\n" + 
-			"}\n" + 
-			"interface IN2 extends IN0 {\n" + 
-			"}\n" + 
-			"public class X {\n" + 
-			"  public X() {\n" + 
-			"  }\n" + 
-			"  IN1 n_1(int ijk) {\n" + 
-			"  }\n" + 
-			"  IN2 n_2() {\n" + 
-			"  }\n" + 
-			"  <M>void m(Supplier<M> m2) {\n" + 
-			"  }\n" + 
-			"  void testSw(int ijk) {\n" + 
-			"    m(switch (ijk) {\n" + 
-			"default ->\n" + 
-			" () -> <SelectOnMessageSend:n_1(ijk)>;\n" + 
-			"});\n" + 
-			"  }\n" + 
-			"}\n";
-	String expectedReplacedSource = "n_1(ijk)";
-	String testName = "X.java";
-
-	int selectionStart = string.lastIndexOf(selection);
-	int selectionEnd = selectionStart + selection.length() - 1;
-
-	checkMethodParse(string.toCharArray(), selectionStart, selectionEnd, expectedSelection, expectedUnitDisplayString,
-			selectionIdentifier, expectedReplacedSource, testName);
-}
-public void test022() throws JavaModelException {
-	String string =  "import org.eclipse.jdt.annotation.*;\n" + 
-			"import java.util.function.*;\n" + 
-			"interface IN0 {} \n" + 
-			"interface IN1 extends IN0 {} \n" + 
-			"interface IN2 extends IN0 {}\n" + 
-			"public class X {\n" + 
-			"	 IN1 n_1(int ijk) { return new IN1() {}; } \n" + 
-			"	IN2 n_2() { return null; } \n" + 
-			"	<M> void m( Supplier< M> m2) { } \n" + 
-			"	void testSw(int ijk) { \n" + 
-			"		m(switch(ijk) { \n" + 
-			"			default -> () -> n_1(ijk); }); \n" + 
-			"	}\n" + 
-			"}";
-
-	String selection = "ijk";
-	String selectKey = "<SelectOnName:";
-	String expectedSelection = selectKey + selection + ">";
-
-	String selectionIdentifier = "ijk";
-	String expectedUnitDisplayString =
-			"import org.eclipse.jdt.annotation.*;\n" + 
-			"import java.util.function.*;\n" + 
-			"interface IN0 {\n" + 
-			"}\n" + 
-			"interface IN1 extends IN0 {\n" + 
-			"}\n" + 
-			"interface IN2 extends IN0 {\n" + 
-			"}\n" + 
-			"public class X {\n" + 
-			"  public X() {\n" + 
-			"  }\n" + 
-			"  IN1 n_1(int ijk) {\n" + 
-			"  }\n" + 
-			"  IN2 n_2() {\n" + 
-			"  }\n" + 
-			"  <M>void m(Supplier<M> m2) {\n" + 
-			"  }\n" + 
-			"  void testSw(int ijk) {\n" + 
-			"    m(switch (ijk) {\n" + 
-			"default ->\n" + 
-			" () -> n_1(<SelectOnName:ijk>);\n" + 
-			"});\n" + 
-			"  }\n" + 
-			"}\n";
-	String expectedReplacedSource = "ijk";
-	String testName = "X.java";
-
-	int selectionStart = string.lastIndexOf(selection);
-	int selectionEnd = selectionStart + selection.length() - 1;
-
-	checkMethodParse(string.toCharArray(), selectionStart, selectionEnd, expectedSelection, expectedUnitDisplayString,
-			selectionIdentifier, expectedReplacedSource, testName);
-}
 }
