@@ -21,6 +21,7 @@ import java.io.File;
 import java.io.FileWriter;
 import java.io.IOException;
 import java.io.Writer;
+import java.util.HashMap;
 import java.util.Hashtable;
 import java.util.List;
 import java.util.Map;
@@ -32,7 +33,6 @@ import org.eclipse.jdt.core.dom.AST;
 import org.eclipse.jdt.core.dom.ASTNode;
 import org.eclipse.jdt.core.dom.ASTParser;
 import org.eclipse.jdt.core.dom.Block;
-import org.eclipse.jdt.core.dom.BreakStatement;
 import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.dom.Expression;
 import org.eclipse.jdt.core.dom.ExpressionStatement;
@@ -55,6 +55,7 @@ import org.eclipse.jdt.core.dom.Type;
 import org.eclipse.jdt.core.dom.TypeDeclaration;
 import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
 import org.eclipse.jdt.core.dom.VariableDeclarationStatement;
+import org.eclipse.jdt.core.dom.YieldStatement;
 import org.eclipse.jdt.core.tests.compiler.regression.AbstractRegressionTest;
 import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 
@@ -64,7 +65,7 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 		super(name);
 	}
 	
-	private static final int AST_JLS_LATEST = AST.JLS12;
+	private static final int AST_JLS_LATEST = AST.JLS13;
 
 	public ASTNode runConversion(
 			int astLevel,
@@ -84,6 +85,13 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 		parser.setUnitName(unitName);
 		return parser.createAST(null);
 	}
+	protected File createFile(File dir, String fileName, String contents) throws IOException {
+		File file = new File(dir, fileName);
+		try (Writer writer = new BufferedWriter(new FileWriter(file))) {
+			writer.write(contents);
+		}
+		return file;
+	}
 	public void testBug529654_001() {
 		String contents =
 				"module m {\n" + 
@@ -1591,7 +1599,7 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 					super.acceptAST(sourceFilePath, ast);
 				}
 			};
-			ASTParser parser = ASTParser.newParser(AST.JLS11);
+			ASTParser parser = ASTParser.newParser(AST_JLS_LATEST);
 			parser.setResolveBindings(true);
 			parser.setStatementsRecovery(true);
 			parser.setBindingsRecovery(true);
@@ -1622,7 +1630,7 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 				"       for (var i = 0; i < 10; ++i) {}\n" +
 				"	}\n" +
 				"}";
-	    ASTParser parser = ASTParser.newParser(AST.JLS11);
+	    ASTParser parser = ASTParser.newParser(AST_JLS_LATEST);
 	    parser.setSource(contents.toCharArray());
 		parser.setStatementsRecovery(true);
 		parser.setBindingsRecovery(true);
@@ -1758,6 +1766,7 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 			SimpleName simpleName = (SimpleName) name;
 			assertFalse("A var", simpleName.isVar());
 	}
+	@Deprecated
 	public void testBug545383_01() throws JavaModelException {
 		String contents =
 				"class X {\n"+
@@ -1782,6 +1791,37 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 		options.put(CompilerOptions.OPTION_ReportPreviewFeatures, CompilerOptions.IGNORE);
 		parser.setCompilerOptions(options);
 	
+		ASTNode node = parser.createAST(null);
+		assertTrue("Should be a compilation unit", node instanceof CompilationUnit);
+		CompilationUnit cu = (CompilationUnit) node;
+		IProblem[] problems = cu.getProblems();
+		assertTrue(problems.length > 0);
+		assertTrue(problems[0].toString().contains("preview"));
+	}	
+	public void testBug547900_01() throws JavaModelException {
+		String contents =
+				"class X {\n"+
+				"	public static int foo(int i) {\n"+
+				"		int result = switch (i) {\n"+
+				"		case 1 -> {yield 5;}\n"+
+				"		default -> 0;\n"+
+				"		};\n"+
+				"		return result;\n"+
+				"	}\n"+
+				"}\n";
+
+		ASTParser parser = ASTParser.newParser(AST_JLS_LATEST);
+		parser.setSource(contents.toCharArray());
+		parser.setEnvironment(null, null, null, true);
+		parser.setResolveBindings(false);
+		Map<String, String> options = getCompilerOptions();
+		options.put(JavaCore.COMPILER_COMPLIANCE, JavaCore.VERSION_13);
+		options.put(JavaCore.COMPILER_SOURCE, JavaCore.VERSION_13);
+		options.put(JavaCore.COMPILER_CODEGEN_TARGET_PLATFORM, JavaCore.VERSION_13);
+		options.put(CompilerOptions.OPTION_EnablePreviews, CompilerOptions.ENABLED);
+		options.put(CompilerOptions.OPTION_ReportPreviewFeatures, CompilerOptions.IGNORE);
+		parser.setCompilerOptions(options);
+	
 		ASTNode node = parser.createAST(null);
 		assertTrue("Should be a compilation unit", node instanceof CompilationUnit);
 		CompilationUnit cu = (CompilationUnit) node;
@@ -1791,8 +1831,55 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 		VariableDeclarationStatement stmt = (VariableDeclarationStatement) methodDeclaration.getBody().statements().get(0);
 		VariableDeclarationFragment fragment = (VariableDeclarationFragment) stmt.fragments().get(0);
 		SwitchExpression se = (SwitchExpression) fragment.getInitializer();
-		BreakStatement breakStatement = (BreakStatement) ((Block)se.statements().get(1)).statements().get(0);
-		assertNull("Unexpected Non null label", breakStatement.getLabel());
-		assertNotNull("Expression null", breakStatement.getExpression());
-	}	
+		YieldStatement yieldStatement = (YieldStatement) ((Block)se.statements().get(1)).statements().get(0);
+		assertNotNull("Expression null", yieldStatement.getExpression());
+	}
+	public void testBug558517() throws IOException {
+		File f1 = null, f2 = null, packDir = null;
+		try {
+			File rootDir = new File(System.getProperty("java.io.tmpdir"));
+			packDir = new File(rootDir, "P/src/x");
+			packDir.mkdirs();
+
+			String fileName1 = "EnsureImpl$1.java";
+			String fileName2 = "C9947f.java";
+			f1 = createFile(
+					packDir, fileName1,
+					"package x;\n" + 
+					"\n" + 
+					"class EnsureImpl$1 {\n" + 
+					"}\n");
+			f2 = createFile(
+					packDir, fileName2,
+					"package x;\n" + 
+					"public final class C9947f {\n" + 
+					"    public C9947f() {\n" + 
+					"        try {\n" + 
+					"            new x.EnsureImpl$1();\n" + 
+					"        } catch (Throwable unused) {\n" + 
+					"        }\n" + 
+					"    }\n" + 
+					"}\n");
+			ASTParser parser = ASTParser.newParser(AST_JLS_LATEST);
+			parser.setResolveBindings(true);
+			Map<String, String> options = new HashMap<>();
+			JavaCore.setComplianceOptions(JavaCore.VERSION_1_8, options);
+			parser.setCompilerOptions(options );
+			parser.setEnvironment(null,
+					new String[] { rootDir + "/P/src" },
+					null,
+					true);
+			parser.createASTs(new String[] { packDir + "/" + fileName1, packDir + "/" + fileName2 },
+					null,
+					new String[] { "Lx/C9947f;" },
+					new FileASTRequestor() {
+					},
+					null);
+			// just ensure the above doesn't throw NPE
+		} finally {
+			f1.delete();
+			f2.delete();
+			packDir.delete();
+		}
+	}
 }
\ No newline at end of file
