@@ -660,13 +660,16 @@ public boolean verifyClassFilesThrowingError(String sourceFilePath, String class
  */
 private void waitForFullBuffers() {
 	String endString = VerifyTests.class.getName();
-	int count = 50;
+	int count = 60;
+	int waitMs = 1;
 	int errorEndStringStart = this.errorBuffer.toString().indexOf(endString);
 	int outputEndStringStart = this.outputBuffer.toString().indexOf(endString);
 	while (errorEndStringStart == -1 || outputEndStringStart == -1) {
 		try {
-			Thread.sleep(100);
+			Thread.sleep(waitMs);
 		} catch (InterruptedException e) {
+		} finally {
+			if(waitMs < 100) waitMs *= 2;
 		}
 		if (--count == 0) return;
 		errorEndStringStart = this.errorBuffer.toString().indexOf(endString);
