@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2011, 2016 GK Software AG and others.
+ * Copyright (c) 2011, 2020 GK Software AG and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -19,8 +19,10 @@ import java.lang.annotation.ElementType;
 import java.lang.annotation.Target;
 import java.io.ByteArrayInputStream;
 import java.net.URL;
+import java.util.HashMap;
 import java.util.Hashtable;
 import java.util.List;
+import java.util.Map;
 
 import junit.framework.Test;
 
@@ -30,6 +32,7 @@ import org.eclipse.core.resources.IResource;
 import org.eclipse.core.resources.IncrementalProjectBuilder;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.FileLocator;
+import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.Platform;
 import org.eclipse.jdt.annotation.NonNull;
 import org.eclipse.jdt.core.IAnnotation;
@@ -42,13 +45,20 @@ import org.eclipse.jdt.core.IType;
 import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.compiler.IProblem;
+import org.eclipse.jdt.core.dom.AST;
 import org.eclipse.jdt.core.dom.ASTParser;
+import org.eclipse.jdt.core.dom.AbstractTypeDeclaration;
 import org.eclipse.jdt.core.dom.CompilationUnit;
+import org.eclipse.jdt.core.dom.FieldDeclaration;
+import org.eclipse.jdt.core.dom.IAnnotationBinding;
+import org.eclipse.jdt.core.dom.ITypeBinding;
 import org.eclipse.jdt.core.dom.MarkerAnnotation;
 import org.eclipse.jdt.core.dom.MethodDeclaration;
 import org.eclipse.jdt.core.dom.Modifier;
 import org.eclipse.jdt.core.dom.SingleVariableDeclaration;
 import org.eclipse.jdt.core.dom.TypeDeclaration;
+import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
+import org.eclipse.jdt.core.tests.util.Util;
 import org.osgi.framework.Bundle;
 
 @SuppressWarnings("rawtypes")
@@ -296,7 +306,7 @@ public class NullAnnotationModelTests extends ReconcilerTests {
 					"Buildpath problem: the type invalid, which is configured as a null annotation type, cannot be resolved\n" +
 					"----------\n");
 
-			ASTParser parser = ASTParser.newParser(AST_INTERNAL_JLS11);
+			ASTParser parser = ASTParser.newParser(AST_INTERNAL_LATEST);
 			parser.setProject(p);
 			parser.setResolveBindings(true);
 			parser.setSource(unit);
@@ -359,7 +369,7 @@ public class NullAnnotationModelTests extends ReconcilerTests {
 			assertEquals("Should have no markers", 0, markers.length);
 
 			// Challenge CompilationUnitResolver:
-			ASTParser parser = ASTParser.newParser(AST_INTERNAL_JLS11);
+			ASTParser parser = ASTParser.newParser(AST_INTERNAL_LATEST);
 			parser.setProject(p);
 			parser.setResolveBindings(true);
 			parser.setSource(unit);
@@ -430,7 +440,7 @@ public class NullAnnotationModelTests extends ReconcilerTests {
 			assertEquals("Unexpected marker path", "/P/p1/C1.java", markers[0].getResource().getFullPath().toString());
 
 			// Challenge CompilationUnitResolver:
-			ASTParser parser = ASTParser.newParser(AST_INTERNAL_JLS11);
+			ASTParser parser = ASTParser.newParser(AST_INTERNAL_LATEST);
 			parser.setProject(p);
 			parser.setResolveBindings(true);
 			parser.setSource(unit);
@@ -483,7 +493,7 @@ public class NullAnnotationModelTests extends ReconcilerTests {
 			final ICompilationUnit unit = getCompilationUnit("/P/p1/C1.java").getWorkingCopy(this.wcOwner, null);
 			assertNoProblem(c1SourceString.toCharArray(), unit);
 
-			ASTParser parser = ASTParser.newParser(AST_INTERNAL_JLS11);
+			ASTParser parser = ASTParser.newParser(AST_INTERNAL_LATEST);
 			parser.setProject(p);
 			parser.setResolveBindings(true);
 			parser.setSource(unit);
@@ -1003,4 +1013,127 @@ public class NullAnnotationModelTests extends ReconcilerTests {
 			deleteProject(client);
 		}
 	}
+	public void testBug549764() throws CoreException, IOException {
+		IJavaProject project = null;
+    	try {
+			project = createJavaProject("Bug549764", new String[] {"src"}, new String[] {"JCL18_LIB", this.ANNOTATION_LIB}, "bin", "1.8");
+			project.setOption(JavaCore.COMPILER_ANNOTATION_NULL_ANALYSIS, JavaCore.ENABLED);
+			
+			IPath libpath = project.getProject().getLocation().append("libann.jar");
+			Util.createJar(new String[] {
+					"lib/MyGenerated.java",
+					"package lib;\n" +
+					"public @interface MyGenerated {\n" +
+					"	String value();\n" +
+					"}"},
+					libpath.toOSString(),
+					"1.8");
+			addLibraryEntry(project, libpath, false);
+
+			createFolder("Bug549764/src/nullAnalysis");
+			createFile("Bug549764/src/nullAnalysis/package-info.java",
+					"@org.eclipse.jdt.annotation.NonNullByDefault\n" + 
+					"package nullAnalysis;");
+			String testSource =
+					"package nullAnalysis;\n" + 
+					"\n" + 
+					"import org.eclipse.jdt.annotation.NonNull;\n" + 
+					"import lib.MyGenerated;\n" + 
+					"\n" + 
+					"@MyGenerated(Endpoint.COMMENT)\n" + 
+					"public class Endpoint {\n" + 
+					"\n" + 
+					"	public static final String COMMENT = \" comment\";\n" + 
+					"\n" + 
+					"	public void method() {\n" + 
+					"		format(COMMENT, \"\");\n" + 
+					"	}\n" + 
+					"	native void format(@NonNull String comment, String arg);\n" + 
+					"}\n";
+			String testSourcePath = "Bug549764/src/nullAnalysis/Endpoint.java";
+			createFile(testSourcePath, testSource);
+			char[] testSourceChars = testSource.toCharArray();
+			this.problemRequestor.initialize(testSourceChars);
+
+			getCompilationUnit(testSourcePath).getWorkingCopy(this.wcOwner, null);
+			assertProblems(
+					"Unexpected problems",
+					"----------\n" + 
+					"1. WARNING in /Bug549764/src/nullAnalysis/Endpoint.java (at line 14)\n" + 
+					"	native void format(@NonNull String comment, String arg);\n" + 
+					"	                   ^^^^^^^^^^^^^^^^^^^^^^^\n" + 
+					"The nullness annotation is redundant with a default that applies to this location\n" + 
+					"----------\n"
+					);
+    	} finally {
+    		deleteProject(project);
+    	}
+	}
+	
+	// was: NPE in SourceTypeBinding.getAnnotationTagBits
+	@SuppressWarnings("deprecation")
+	public void testBug551426() throws CoreException, Exception {
+		ASTParser astParser = ASTParser.newParser(AST.JLS8);
+		Map<String, String> options = new HashMap<>();
+		astParser.setResolveBindings(true);
+		astParser.setEnvironment(new String[] {}, new String[] {}, new String[] {}, true);
+		options.put(JavaCore.COMPILER_SOURCE, "1.8");
+		options.put(JavaCore.COMPILER_COMPLIANCE, "1.8");
+		astParser.setCompilerOptions(options);
+		astParser.setUnitName("C.java");
+		String source = 
+				"class C {\n" + 
+				"  public static final Object f = new Object() {};\n" +
+				"}\n";
+		astParser.setSource(source.toCharArray());
+		CompilationUnit astNode = (CompilationUnit) astParser.createAST(null);
+		AbstractTypeDeclaration typeDeclaration = (AbstractTypeDeclaration) astNode.types().get(0);
+		FieldDeclaration fieldDeclaration = (FieldDeclaration) typeDeclaration.bodyDeclarations().get(0);
+		VariableDeclarationFragment fragment = (VariableDeclarationFragment) fieldDeclaration.fragments().get(0);
+		ITypeBinding typeBinding = fragment.getInitializer().resolveTypeBinding();
+		IAnnotationBinding[] annotations = typeBinding.getAnnotations();
+		assertEquals(0, annotations.length);
+	}
+	public void testBug479389() throws CoreException, IOException {
+		IJavaProject project = null;
+		try {
+			project = createJavaProject("Bug479389", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", "1.8");
+			project.setOption(JavaCore.COMPILER_ANNOTATION_NULL_ANALYSIS, JavaCore.ENABLED);
+			
+			createFolder("Bug479389/src/nullAnalysis");
+			String testSource =
+					"package nullAnalysis;\n" + 
+					"interface MyList<T> {\n" +
+					"	public Stream<T> stream();\n" +
+					"}\n" +
+					"interface Stream<T> {\n" +
+					"	T[] toArray(IntFunction<T[]> supplier);" +
+					"}\n" +
+					"interface IntFunction<T> {\n" +
+					"	T apply(int i);\n" +
+					"}\n" + 
+					"public class X {\n" + 
+					"\n" + 
+					"	public String[] method(MyList<String> in) {\n" + 
+					"		return in.stream().toArray(String[]::new);\n" + 
+					"	}\n" + 
+					"}\n";
+			String testSourcePath = "Bug479389/src/nullAnalysis/X.java";
+			createFile(testSourcePath, testSource);
+			char[] testSourceChars = testSource.toCharArray();
+			this.problemRequestor.initialize(testSourceChars);
+
+			getCompilationUnit(testSourcePath).getWorkingCopy(this.wcOwner, null);
+			assertProblems(
+					"Unexpected problems",
+					"----------\n" + 
+					"1. ERROR in /Bug479389/src/nullAnalysis/X.java (at line 13)\n" + 
+					"	return in.stream().toArray(String[]::new);\n" + 
+					"	       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n" + 
+					"Annotation type \'org.eclipse.jdt.annotation.NonNull\' cannot be found on the build path, which is implicitly needed for null analysis\n" + 
+					"----------\n"					);
+		} finally {
+			deleteProject(project);
+		}
+	}
 }
