@@ -15,6 +15,7 @@
 package org.eclipse.jdt.core.tests.model;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashSet;
 import java.util.Hashtable;
 import java.util.Iterator;
@@ -530,7 +531,7 @@ public void test12() throws CoreException {
 		IJavaProject project = createJavaProject("P", new String[0], new String[] {"TEST"}, "");
 		waitForAutoBuild();
 		preferences.put(JavaModelManager.CP_VARIABLE_PREFERENCES_PREFIX+"TEST", getExternalJCLPathString());
-		assertMarkers("Unexpected markers", "", project);
+		assertBuildPathMarkers("Unexpected markers", "", project);
 	} finally {
 		deleteProject("P");
 		preferences.remove(JavaModelManager.CP_VARIABLE_PREFERENCES_PREFIX+"TEST");
@@ -959,4 +960,13 @@ public void testBug324987_Workspace04() throws CoreException {
 		deleteProject("P");
 	}
 }
+public void testBug550081() {
+	String latestVersion = JavaCore.latestSupportedJavaVersion();
+	try {
+		Collections.reverse(JavaCore.getAllVersions());
+	} catch (UnsupportedOperationException e) {
+		// ignore
+	}
+	assertEquals("latest should be unchanged", latestVersion, JavaCore.latestSupportedJavaVersion());
+}
 }
