@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -1920,6 +1920,32 @@ public void test029() throws CoreException {
 		deleteFile("/P/src/X.java");
 	}
 }
+@SuppressWarnings("deprecation")
+public void testBug543073_001() throws CoreException {
+	try {
+		this.createFile(
+			"/P/src/X.java",
+			"public enum X {\n" +
+			"	Z, A, C, B;\n" +
+			"}"
+		);
+		String expectedResult =
+			"public enum X {\n" +
+			"	Z, A, C, B;\n" +
+			"}";
+		sortUnit(AST_INTERNAL_JLS10, this.getCompilationUnit("/P/src/X.java"), expectedResult, false, new Comparator() {
+			public int compare(Object o1, Object o2) {
+				BodyDeclaration bodyDeclaration1 = (BodyDeclaration) o1;
+				BodyDeclaration bodyDeclaration2 = (BodyDeclaration) o2;
+				final int sourceStart1 = ((Integer) bodyDeclaration1.getProperty(CompilationUnitSorter.RELATIVE_ORDER)).intValue();
+				final int sourceStart2 = ((Integer) bodyDeclaration2.getProperty(CompilationUnitSorter.RELATIVE_ORDER)).intValue();
+				return sourceStart1 - sourceStart2;
+			}
+		});
+	} finally {
+		deleteFile("/P/src/X.java");
+	}
+}
 //https://bugs.eclipse.org/bugs/show_bug.cgi?id=113722
 public void test030() throws CoreException {
 	try {
